--[[
This file is part of Twinnings - a puzzle game

Twinnings is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This software is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
]]

SAVE_FILE = 'save'

function save_game(t)
	local function serialize(o, data) -- adapted from "Programming in Lua"
		data = data or ''
		if type(o) == 'number' then
			data = data .. o
		elseif type(o) == 'string' then
			data = data .. string.format('%q', o)
		elseif type(o) == 'boolean' then
			if o then data = data .. 'true' else data = data .. 'false' end
		elseif type(o) == 'table' then
			data = data .. '{\n'
		for k,v in pairs(o) do
			if type(k) == 'number' then
				data = data .. '  [' .. k .. '] = '
			else
				data = data .. '  ' .. k .. ' = '
			end
			data = data .. serialize(v)
			data = data .. ',\n'
		end
			data = data .. '}\n'
		else
			error('cannot serialize a ' .. type(o))
		end
		return data
	end
	local ok, err = love.filesystem.write(SAVE_FILE, 'return ' .. serialize(t))
	if not ok then error(err) end
end


function load_game()
	local saved_game, err = love.filesystem.load(SAVE_FILE)
	if not err then
		return saved_game()
	end
end

function del_game()
	love.filesystem.remove(SAVE_FILE)
end